<template>
	<div class="sys-user-container">
		<el-row>
			<el-col :span="5">
				<el-row style="display: flex;text-align: center;justify-content: center;height: 40px;">
					<el-button type="warning" style="width: 95%;height: 30px;" @click="reset">报警复位</el-button>
				</el-row>
				<el-table :data="paginatedData" border style="width: 100%" v-loading="loading"
					:default-sort="{ prop: 'date', order: 'descending' }">
					<el-table-column prop="alarmCode" label="变量" align="center"></el-table-column>
					<el-table-column prop="alarmName" label="描述" align="center"></el-table-column>
					<el-table-column prop="stationNum" label="位置" align="center"></el-table-column>
					<el-table-column prop="alarmTime" label="时间" align="center"></el-table-column>
				</el-table>
				<el-pagination v-model:currentPage="tableParams.page" v-model:page-size="tableParams.pageSize"
					:total="tableParams.total" :page-sizes="[10, 20, 50, 100, 200, 500]" size="small" background=""
					@size-change="handleSizeChange" @current-change="handleCurrentChange" layout="prev, pager, next" />
			</el-col>
			<el-col :span="19">
				<div class="card-page">
					<el-button type="primary" :plain="layer != 1" @click="floorTogglePlain(1)">一层平面</el-button>
					<el-button type="primary" :plain="layer != 2" @click="floorTogglePlain(2)">二层平面</el-button>
					<el-button type="primary" :plain="layer != 3" @click="floorTogglePlain(3)">三层平面</el-button>
				</div>
				<div style="margin: 40px; height: 50%;">
					<div class="grid-container-line">
						<div v-for="cell in cellsDataLine" :key="cell.Id">
							<div v-if="cell.IsShow === 0" class="grid-item-line">
								<div class="grid-item-line-end">
									{{ cell.EndLocat }}
								</div>
								<div class="grid-item-line-box" :style="{ marginTop: cell.BoxHeight + 'px' }">
									{{ cell.LineCode }}
								</div>
								<div class="grid-item-line-child"></div>
							</div>
						</div>
					</div>
					<div class="grid-container">
						<div v-for="cell in cellsData">
							<!-- IsUse状态 0:正常 1：有物品 2：非工位 3：小车路线 4：故障 -->
							<div v-if="cell.IsShow === 0"
								:class="['grid-item', { 'active': cell.IsUse === 1 }, { 'active2': cell.IsUse === 2 }, { 'active3': cell.IsUse === 3 }, { 'active3': cell.IsUse === 3 }, { 'active4': cell.IsUse === 4 }]">
								<div>{{ cell.Code }}</div>
							</div>
						</div>
					</div>
				</div>
			</el-col>
		</el-row>
	</div>
</template>

<script lang="ts" setup>
import { ref, reactive, onMounted, computed } from 'vue';
import 'splitpanes/dist/splitpanes.css';
import { listWcsAlarmInfo, resetWcsAlarmInfo } from '/@/api/wcs/wcsAlarmInfo';
import { signalR } from './signalR';
//连接signalR 监听变更
onMounted(async () => {
	signalR.off('PublicAlarm');
	signalR.on('PublicAlarm', (dataArray: any) => {
		dataArray.forEach(data => {
			console.log(data);
			// 更新 tableData
			const index = tableData.value.findIndex(t => t.id == data.id);
			if (index === -1 && data.status == 1) {
				// 如果不存在，添加新数据
				tableData.value.unshift(data);
				tableParams.value.total = tableData.value.length;
			} else {
				if (data.status == 1) {
					// 如果状态为 1，更新数据
					if (index !== -1) {
						tableData.value.splice(index, 1, data);
					}
				} else {
					// 如果状态不是 1，报警消除
					if (index !== -1) {
						tableData.value.splice(index, 1);
					}
				}
			}

			// 更新输送线数据
			updateCellData(cellsDataOne.value, data);
			updateCellData(cellsDataTwo.value, data);
			updateCellData(cellsDataThree.value, data);
		});
	});
});
// 更新输送线数据的通用函数
function updateCellData(cellsData: any[], data: any) {
	const foundCell = cellsData.find(cell => cell.Code === data.stationNum);
	if (foundCell) {
		if (data.status == 1) {
			foundCell.IsUse = 4;
		}
		else {
			foundCell.IsUse = 0;
		}
	}
}
// 改变页面容量
const handleSizeChange = (val: number) => {
	tableParams.value.pageSize = val;
};

// 改变页码序号
const handleCurrentChange = (val: number) => {
	tableParams.value.page = val;
};
//表格显示数据
const paginatedData = computed(() => {
	const start = (tableParams.value.page - 1) * tableParams.value.pageSize
	const end = start + tableParams.value.pageSize
	return tableData.value.slice(start, end)
})
//堆垛机数据
const cellsDataLine = [
	{ Id: 1, Code: '001', LineCode: '', EndLocat: '', IsShow: 1, IsUse: 0, BoxHeight: 10 },
	{ Id: 2, Code: '002', LineCode: '01', EndLocat: '', IsShow: 0, IsUse: 0, BoxHeight: 210 },
	{ Id: 3, Code: '003', LineCode: '', EndLocat: '', IsShow: 1, IsUse: 0, BoxHeight: 10 },
	{ Id: 4, Code: '004', LineCode: '', EndLocat: '', IsShow: 1, IsUse: 0, BoxHeight: 10 },
	{ Id: 5, Code: '005', LineCode: '', EndLocat: '', IsShow: 1, IsUse: 0, BoxHeight: 10 },
	{ Id: 6, Code: '006', LineCode: '02', EndLocat: '', IsShow: 0, IsUse: 0, BoxHeight: 210 },
	{ Id: 7, Code: '007', LineCode: '', EndLocat: '', IsShow: 1, IsUse: 0, BoxHeight: 10 },
	{ Id: 8, Code: '008', LineCode: '', EndLocat: '', IsShow: 1, IsUse: 0, BoxHeight: 10 },
	{ Id: 9, Code: '009', LineCode: '', EndLocat: '', IsShow: 1, IsUse: 0, BoxHeight: 10 },
	{ Id: 10, Code: '010', LineCode: '', EndLocat: '', IsShow: 1, IsUse: 0, BoxHeight: 10 },
	{ Id: 11, Code: '011', LineCode: '', EndLocat: '', IsShow: 1, IsUse: 0, BoxHeight: 10 },
	{ Id: 12, Code: '012', LineCode: '03', EndLocat: '', IsShow: 0, IsUse: 0, BoxHeight: 210 },
	{ Id: 13, Code: '013', LineCode: '', EndLocat: '', IsShow: 1, IsUse: 0, BoxHeight: 10 },
	{ Id: 14, Code: '014', LineCode: '', EndLocat: '', IsShow: 1, IsUse: 0, BoxHeight: 10 },
	{ Id: 15, Code: '015', LineCode: '', EndLocat: '', IsShow: 1, IsUse: 0, BoxHeight: 10 },
	{ Id: 16, Code: '016', LineCode: '', EndLocat: '', IsShow: 1, IsUse: 0, BoxHeight: 10 },
	{ Id: 17, Code: '017', LineCode: '04', EndLocat: '', IsShow: 0, IsUse: 0, BoxHeight: 210 },
	{ Id: 18, Code: '018', LineCode: '', EndLocat: '', IsShow: 1, IsUse: 0, BoxHeight: 10 },
	{ Id: 19, Code: '019', LineCode: '', EndLocat: '', IsShow: 1, IsUse: 0, BoxHeight: 10 },
	{ Id: 20, Code: '020', LineCode: '', EndLocat: '', IsShow: 1, IsUse: 0, BoxHeight: 10 },
	{ Id: 21, Code: '021', LineCode: '', EndLocat: '', IsShow: 1, IsUse: 0, BoxHeight: 10 },
	{ Id: 22, Code: '022', LineCode: '', EndLocat: '', IsShow: 1, IsUse: 0, BoxHeight: 10 },
	{ Id: 23, Code: '023', LineCode: '05', EndLocat: '', IsShow: 0, IsUse: 0, BoxHeight: 210 },
	{ Id: 24, Code: '024', LineCode: '', EndLocat: '', IsShow: 1, IsUse: 0, BoxHeight: 10 },
	{ Id: 25, Code: '025', LineCode: '', EndLocat: '', IsShow: 1, IsUse: 0, BoxHeight: 10 },
	{ Id: 26, Code: '026', LineCode: '', EndLocat: '', IsShow: 1, IsUse: 0, BoxHeight: 10 },
	{ Id: 27, Code: '027', LineCode: '', EndLocat: '', IsShow: 1, IsUse: 0, BoxHeight: 10 },
	{ Id: 28, Code: '028', LineCode: '06', EndLocat: '', IsShow: 0, IsUse: 0, BoxHeight: 210 },
	{ Id: 29, Code: '029', LineCode: '', EndLocat: '', IsShow: 1, IsUse: 0, BoxHeight: 10 },
	{ Id: 30, Code: '030', LineCode: '', EndLocat: '', IsShow: 1, IsUse: 0, BoxHeight: 10 },
	{ Id: 31, Code: '031', LineCode: '', EndLocat: '', IsShow: 1, IsUse: 0, BoxHeight: 10 },
	{ Id: 32, Code: '032', LineCode: '', EndLocat: '', IsShow: 1, IsUse: 0, BoxHeight: 10 },
	{ Id: 33, Code: '033', LineCode: '', EndLocat: '', IsShow: 1, IsUse: 0, BoxHeight: 10 },
	{ Id: 34, Code: '034', LineCode: '07', EndLocat: '', IsShow: 0, IsUse: 0, BoxHeight: 210 },
	{ Id: 35, Code: '035', LineCode: '', EndLocat: '', IsShow: 1, IsUse: 0, BoxHeight: 10 },
	{ Id: 36, Code: '036', LineCode: '', EndLocat: '', IsShow: 1, IsUse: 0, BoxHeight: 10 },
	{ Id: 37, Code: '037', LineCode: '', EndLocat: '', IsShow: 1, IsUse: 0, BoxHeight: 10 },
	{ Id: 38, Code: '038', LineCode: '', EndLocat: '', IsShow: 1, IsUse: 0, BoxHeight: 10 },
	{ Id: 39, Code: '039', LineCode: '08', EndLocat: '', IsShow: 0, IsUse: 0, BoxHeight: 210 },
	{ Id: 40, Code: '040', LineCode: '', EndLocat: '', IsShow: 1, IsUse: 0, BoxHeight: 10 },
	{ Id: 41, Code: '041', LineCode: '', EndLocat: '', IsShow: 1, IsUse: 0, BoxHeight: 10 },
	{ Id: 42, Code: '042', LineCode: '', EndLocat: '', IsShow: 1, IsUse: 0, BoxHeight: 10 },
	{ Id: 43, Code: '043', LineCode: '', EndLocat: '', IsShow: 1, IsUse: 0, BoxHeight: 10 },
	{ Id: 44, Code: '044', LineCode: '', EndLocat: '', IsShow: 1, IsUse: 0, BoxHeight: 10 },
	{ Id: 45, Code: '045', LineCode: '09', EndLocat: '', IsShow: 0, IsUse: 0, BoxHeight: 210 },
	{ Id: 46, Code: '046', LineCode: '', EndLocat: '', IsShow: 1, IsUse: 0, BoxHeight: 10 },
	{ Id: 47, Code: '047', LineCode: '', EndLocat: '', IsShow: 1, IsUse: 0, BoxHeight: 10 },
	{ Id: 48, Code: '048', LineCode: '', EndLocat: '', IsShow: 1, IsUse: 0, BoxHeight: 10 },
	{ Id: 49, Code: '049', LineCode: '', EndLocat: '', IsShow: 1, IsUse: 0, BoxHeight: 10 },
	{ Id: 50, Code: '050', LineCode: '10', EndLocat: '', IsShow: 0, IsUse: 0, BoxHeight: 210 },
	{ Id: 51, Code: '051', LineCode: '', EndLocat: '', IsShow: 1, IsUse: 0, BoxHeight: 10 },
];
//一层输送线数据
const cellsDataOne = ref([
	{ Id: 1, Code: '147', IsShow: 0, IsUse: 0 },
	{ Id: 2, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 3, Code: '145', IsShow: 0, IsUse: 0 },
	{ Id: 4, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 5, Code: '139', IsShow: 0, IsUse: 0 },
	{ Id: 6, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 7, Code: '137', IsShow: 0, IsUse: 0 },
	{ Id: 8, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 9, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 10, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 11, Code: '129', IsShow: 0, IsUse: 0 },
	{ Id: 12, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 13, Code: '127', IsShow: 0, IsUse: 0 },
	{ Id: 14, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 15, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 16, Code: '121', IsShow: 0, IsUse: 0 },
	{ Id: 17, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 18, Code: '119', IsShow: 0, IsUse: 0 },
	{ Id: 19, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 20, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 21, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 22, Code: '111', IsShow: 0, IsUse: 0 },
	{ Id: 23, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 24, Code: '109', IsShow: 0, IsUse: 0 },
	{ Id: 25, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 26, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 27, Code: '103', IsShow: 0, IsUse: 0 },
	{ Id: 28, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 29, Code: '101', IsShow: 0, IsUse: 0 },
	{ Id: 30, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 31, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 32, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 33, Code: '093', IsShow: 0, IsUse: 0 },
	{ Id: 34, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 35, Code: '091', IsShow: 0, IsUse: 0 },
	{ Id: 36, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 37, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 38, Code: '085', IsShow: 0, IsUse: 0 },
	{ Id: 39, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 40, Code: '083', IsShow: 0, IsUse: 0 },
	{ Id: 41, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 42, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 43, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 44, Code: '075', IsShow: 0, IsUse: 0 },
	{ Id: 45, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 46, Code: '073', IsShow: 0, IsUse: 0 },
	{ Id: 47, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 48, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 49, Code: '067', IsShow: 0, IsUse: 0 },
	{ Id: 50, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 51, Code: '065', IsShow: 0, IsUse: 0 },
	{ Id: 52, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 53, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 54, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 55, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 56, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 57, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 58, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 59, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 60, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 61, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 62, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 63, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 64, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 65, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 66, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 67, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 68, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 69, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 70, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 71, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 72, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 73, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 74, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 75, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 76, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 77, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 78, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 79, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 80, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 81, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 82, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 83, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 84, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 85, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 86, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 87, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 88, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 89, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 90, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 91, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 92, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 93, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 94, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 95, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 96, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 97, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 98, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 99, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 100, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 101, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 102, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 103, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 104, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 105, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 106, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 107, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 108, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 109, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 110, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 111, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 112, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 113, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 114, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 115, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 116, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 117, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 118, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 119, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 120, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 121, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 122, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 123, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 124, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 125, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 126, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 127, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 128, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 129, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 130, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 131, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 132, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 133, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 134, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 135, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 136, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 137, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 138, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 139, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 140, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 141, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 142, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 143, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 144, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 145, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 146, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 147, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 148, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 149, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 150, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 151, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 152, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 153, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 154, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 155, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 156, Code: '144', IsShow: 0, IsUse: 0 },
	{ Id: 157, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 158, Code: '140', IsShow: 0, IsUse: 0 },
	{ Id: 159, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 160, Code: '136', IsShow: 0, IsUse: 0 },
	{ Id: 161, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 162, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 163, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 164, Code: '130', IsShow: 0, IsUse: 0 },
	{ Id: 165, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 166, Code: '126', IsShow: 0, IsUse: 0 },
	{ Id: 167, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 168, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 169, Code: '122', IsShow: 0, IsUse: 0 },
	{ Id: 170, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 171, Code: '118', IsShow: 0, IsUse: 0 },
	{ Id: 172, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 173, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 174, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 175, Code: '112', IsShow: 0, IsUse: 0 },
	{ Id: 176, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 177, Code: '108', IsShow: 0, IsUse: 0 },
	{ Id: 178, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 179, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 180, Code: '104', IsShow: 0, IsUse: 0 },
	{ Id: 181, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 182, Code: '100', IsShow: 0, IsUse: 0 },
	{ Id: 183, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 184, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 185, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 186, Code: '094', IsShow: 0, IsUse: 0 },
	{ Id: 187, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 188, Code: '090', IsShow: 0, IsUse: 0 },
	{ Id: 189, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 190, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 191, Code: '086', IsShow: 0, IsUse: 0 },
	{ Id: 192, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 193, Code: '082', IsShow: 0, IsUse: 0 },
	{ Id: 194, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 195, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 196, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 197, Code: '076', IsShow: 0, IsUse: 0 },
	{ Id: 198, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 199, Code: '072', IsShow: 0, IsUse: 0 },
	{ Id: 200, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 201, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 202, Code: '068', IsShow: 0, IsUse: 0 },
	{ Id: 203, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 204, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 205, Code: '148', IsShow: 0, IsUse: 0 },
	{ Id: 206, Code: '146', IsShow: 0, IsUse: 0 },
	{ Id: 207, Code: '143', IsShow: 0, IsUse: 0 },
	{ Id: 208, Code: '142', IsShow: 0, IsUse: 0 },
	{ Id: 209, Code: '141', IsShow: 0, IsUse: 0 },
	{ Id: 210, Code: '138', IsShow: 0, IsUse: 0 },
	{ Id: 211, Code: '135', IsShow: 0, IsUse: 0 },
	{ Id: 212, Code: '134', IsShow: 0, IsUse: 0 },
	{ Id: 213, Code: '133', IsShow: 0, IsUse: 0 },
	{ Id: 214, Code: '132', IsShow: 0, IsUse: 0 },
	{ Id: 215, Code: '131', IsShow: 0, IsUse: 0 },
	{ Id: 216, Code: '128', IsShow: 0, IsUse: 0 },
	{ Id: 217, Code: '125', IsShow: 0, IsUse: 0 },
	{ Id: 218, Code: '124', IsShow: 0, IsUse: 0 },
	{ Id: 219, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 220, Code: '123', IsShow: 0, IsUse: 0 },
	{ Id: 221, Code: '120', IsShow: 0, IsUse: 0 },
	{ Id: 222, Code: '117', IsShow: 0, IsUse: 0 },
	{ Id: 223, Code: '116', IsShow: 0, IsUse: 0 },
	{ Id: 224, Code: '115', IsShow: 0, IsUse: 0 },
	{ Id: 225, Code: '114', IsShow: 0, IsUse: 0 },
	{ Id: 226, Code: '113', IsShow: 0, IsUse: 0 },
	{ Id: 227, Code: '110', IsShow: 0, IsUse: 0 },
	{ Id: 228, Code: '107', IsShow: 0, IsUse: 0 },
	{ Id: 229, Code: '106', IsShow: 0, IsUse: 0 },
	{ Id: 230, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 231, Code: '105', IsShow: 0, IsUse: 0 },
	{ Id: 232, Code: '102', IsShow: 0, IsUse: 0 },
	{ Id: 233, Code: '099', IsShow: 0, IsUse: 0 },
	{ Id: 234, Code: '098', IsShow: 0, IsUse: 0 },
	{ Id: 235, Code: '097', IsShow: 0, IsUse: 0 },
	{ Id: 236, Code: '096', IsShow: 0, IsUse: 0 },
	{ Id: 237, Code: '095', IsShow: 0, IsUse: 0 },
	{ Id: 238, Code: '092', IsShow: 0, IsUse: 0 },
	{ Id: 239, Code: '089', IsShow: 0, IsUse: 0 },
	{ Id: 240, Code: '088', IsShow: 0, IsUse: 0 },
	{ Id: 241, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 242, Code: '087', IsShow: 0, IsUse: 0 },
	{ Id: 243, Code: '084', IsShow: 0, IsUse: 0 },
	{ Id: 244, Code: '081', IsShow: 0, IsUse: 0 },
	{ Id: 245, Code: '080', IsShow: 0, IsUse: 0 },
	{ Id: 246, Code: '079', IsShow: 0, IsUse: 0 },
	{ Id: 247, Code: '078', IsShow: 0, IsUse: 0 },
	{ Id: 248, Code: '077', IsShow: 0, IsUse: 0 },
	{ Id: 249, Code: '074', IsShow: 0, IsUse: 0 },
	{ Id: 250, Code: '071', IsShow: 0, IsUse: 0 },
	{ Id: 251, Code: '070', IsShow: 0, IsUse: 0 },
	{ Id: 252, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 253, Code: '069', IsShow: 0, IsUse: 0 },
	{ Id: 254, Code: '066', IsShow: 0, IsUse: 0 },
	{ Id: 255, Code: '064', IsShow: 0, IsUse: 0 },
	{ Id: 256, Code: '149', IsShow: 0, IsUse: 0 },
	{ Id: 257, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 258, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 259, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 260, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 261, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 262, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 263, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 264, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 265, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 266, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 267, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 268, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 269, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 270, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 271, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 272, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 273, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 274, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 275, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 276, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 277, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 278, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 279, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 280, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 281, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 282, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 283, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 284, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 285, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 286, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 287, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 288, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 289, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 290, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 291, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 292, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 293, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 294, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 295, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 296, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 297, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 298, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 299, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 300, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 301, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 302, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 303, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 304, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 305, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 306, Code: '063', IsShow: 0, IsUse: 0 },
	{ Id: 307, Code: '001', IsShow: 0, IsUse: 0 },
	{ Id: 308, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 309, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 310, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 311, Code: '006', IsShow: 0, IsUse: 0 },
	{ Id: 312, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 313, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 314, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 315, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 316, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 317, Code: '015', IsShow: 0, IsUse: 0 },
	{ Id: 318, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 319, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 320, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 321, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 322, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 323, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 324, Code: '030', IsShow: 0, IsUse: 0 },
	{ Id: 325, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 326, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 327, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 328, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 329, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 330, Code: '036', IsShow: 0, IsUse: 0 },
	{ Id: 331, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 332, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 333, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 334, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 335, Code: '042', IsShow: 0, IsUse: 0 },
	{ Id: 336, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 337, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 338, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 339, Code: '047', IsShow: 0, IsUse: 0 },
	{ Id: 340, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 341, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 342, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 343, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 344, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 345, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 346, Code: '054', IsShow: 0, IsUse: 0 },
	{ Id: 347, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 348, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 349, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 350, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 351, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 352, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 353, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 354, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 355, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 356, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 357, Code: '062', IsShow: 0, IsUse: 0 },
	{ Id: 358, Code: '002', IsShow: 0, IsUse: 0 },
	{ Id: 359, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 360, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 361, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 362, Code: '007', IsShow: 0, IsUse: 0 },
	{ Id: 363, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 364, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 365, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 366, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 367, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 368, Code: '016', IsShow: 0, IsUse: 0 },
	{ Id: 369, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 370, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 371, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 372, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 373, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 374, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 375, Code: '029', IsShow: 0, IsUse: 0 },
	{ Id: 376, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 377, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 378, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 379, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 380, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 381, Code: '035', IsShow: 0, IsUse: 0 },
	{ Id: 382, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 383, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 384, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 385, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 386, Code: '041', IsShow: 0, IsUse: 0 },
	{ Id: 387, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 388, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 389, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 390, Code: '046', IsShow: 0, IsUse: 0 },
	{ Id: 391, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 392, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 393, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 394, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 395, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 396, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 397, Code: '053', IsShow: 0, IsUse: 0 },
	{ Id: 398, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 399, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 400, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 401, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 402, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 403, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 404, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 405, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 406, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 407, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 408, Code: '061', IsShow: 0, IsUse: 0 },
	{ Id: 409, Code: '003', IsShow: 0, IsUse: 0 },
	{ Id: 410, Code: '004', IsShow: 0, IsUse: 0 },
	{ Id: 411, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 412, Code: '005', IsShow: 0, IsUse: 0 },
	{ Id: 413, Code: '008', IsShow: 0, IsUse: 0 },
	{ Id: 414, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 415, Code: '010', IsShow: 0, IsUse: 0 },
	{ Id: 416, Code: '011', IsShow: 0, IsUse: 0 },
	{ Id: 417, Code: '014', IsShow: 0, IsUse: 0 },
	{ Id: 418, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 419, Code: '017', IsShow: 0, IsUse: 0 },
	{ Id: 420, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 421, Code: '019', IsShow: 0, IsUse: 0 },
	{ Id: 422, Code: '020', IsShow: 0, IsUse: 0 },
	{ Id: 423, Code: '023', IsShow: 0, IsUse: 0 },
	{ Id: 424, Code: '025', IsShow: 0, IsUse: 0 },
	{ Id: 425, Code: '026', IsShow: 0, IsUse: 0 },
	{ Id: 426, Code: '028', IsShow: 0, IsUse: 0 },
	{ Id: 427, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 428, Code: '031', IsShow: 0, IsUse: 0 },
	{ Id: 429, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 430, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 431, Code: '032', IsShow: 0, IsUse: 0 },
	{ Id: 432, Code: '034', IsShow: 0, IsUse: 0 },
	{ Id: 433, Code: '037', IsShow: 0, IsUse: 0 },
	{ Id: 434, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 435, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 436, Code: '038', IsShow: 0, IsUse: 0 },
	{ Id: 437, Code: '040', IsShow: 0, IsUse: 0 },
	{ Id: 438, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 439, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 440, Code: '043', IsShow: 0, IsUse: 0 },
	{ Id: 441, Code: '045', IsShow: 0, IsUse: 0 },
	{ Id: 442, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 443, Code: '048', IsShow: 0, IsUse: 0 },
	{ Id: 444, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 445, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 446, Code: '049', IsShow: 0, IsUse: 0 },
	{ Id: 447, Code: '050', IsShow: 0, IsUse: 0 },
	{ Id: 448, Code: '052', IsShow: 0, IsUse: 0 },
	{ Id: 449, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 450, Code: '055', IsShow: 0, IsUse: 0 },
	{ Id: 451, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 452, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 453, Code: '056', IsShow: 0, IsUse: 0 },
	{ Id: 454, Code: '057', IsShow: 0, IsUse: 0 },
	{ Id: 455, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 456, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 457, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 458, Code: '058', IsShow: 0, IsUse: 0 },
	{ Id: 459, Code: '060', IsShow: 0, IsUse: 0 },
	{ Id: 460, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 461, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 462, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 463, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 464, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 465, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 466, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 467, Code: '012', IsShow: 0, IsUse: 0 },
	{ Id: 468, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 469, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 470, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 471, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 472, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 473, Code: '021', IsShow: 0, IsUse: 0 },
	{ Id: 474, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 475, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 476, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 477, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 478, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 479, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 480, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 481, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 482, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 483, Code: '033', IsShow: 0, IsUse: 0 },
	{ Id: 484, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 485, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 486, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 487, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 488, Code: '039', IsShow: 0, IsUse: 0 },
	{ Id: 489, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 490, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 491, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 492, Code: '044', IsShow: 0, IsUse: 0 },
	{ Id: 493, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 494, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 495, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 496, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 497, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 498, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 499, Code: '051', IsShow: 0, IsUse: 0 },
	{ Id: 500, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 501, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 502, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 503, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 504, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 505, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 506, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 507, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 508, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 509, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 510, Code: '059', IsShow: 0, IsUse: 0 },
	{ Id: 511, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 512, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 513, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 514, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 515, Code: '009', IsShow: 0, IsUse: 0 },
	{ Id: 516, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 517, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 518, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 519, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 520, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 521, Code: '018', IsShow: 0, IsUse: 0 },
	{ Id: 522, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 523, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 524, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 525, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 526, Code: '024', IsShow: 0, IsUse: 0 },
	{ Id: 527, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 528, Code: '027', IsShow: 0, IsUse: 0 },
	{ Id: 529, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 530, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 531, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 532, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 533, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 534, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 535, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 536, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 537, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 538, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 539, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 540, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 541, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 542, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 543, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 544, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 545, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 546, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 547, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 548, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 549, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 550, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 551, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 552, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 553, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 554, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 555, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 556, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 557, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 558, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 559, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 560, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 561, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 562, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 563, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 564, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 565, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 566, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 567, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 568, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 569, Code: '013', IsShow: 0, IsUse: 0 },
	{ Id: 570, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 571, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 572, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 573, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 574, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 575, Code: '022', IsShow: 0, IsUse: 0 },
	{ Id: 576, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 577, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 578, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 579, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 580, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 581, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 582, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 583, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 584, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 585, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 586, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 587, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 588, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 589, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 590, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 591, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 592, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 593, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 594, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 595, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 596, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 597, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 598, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 599, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 600, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 601, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 602, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 603, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 604, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 605, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 606, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 607, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 608, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 609, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 610, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 611, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 612, Code: '', IsShow: 1, IsUse: 0 },
]);
//二层输送线数据
const cellsDataTwo = ref([
	{ Id: 1, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 2, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 3, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 4, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 5, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 6, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 7, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 8, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 9, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 10, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 11, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 12, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 13, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 14, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 15, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 16, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 17, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 18, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 19, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 20, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 21, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 22, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 23, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 24, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 25, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 26, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 27, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 28, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 29, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 30, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 31, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 32, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 33, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 34, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 35, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 36, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 37, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 38, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 39, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 40, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 41, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 42, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 43, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 44, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 45, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 46, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 47, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 48, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 49, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 50, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 51, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 52, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 53, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 54, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 55, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 56, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 57, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 58, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 59, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 60, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 61, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 62, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 63, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 64, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 65, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 66, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 67, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 68, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 69, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 70, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 71, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 72, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 73, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 74, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 75, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 76, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 77, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 78, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 79, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 80, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 81, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 82, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 83, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 84, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 85, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 86, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 87, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 88, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 89, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 90, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 91, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 92, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 93, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 94, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 95, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 96, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 97, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 98, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 99, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 100, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 101, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 102, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 103, Code: '252', IsShow: 0, IsUse: 0 },
	{ Id: 104, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 105, Code: '254', IsShow: 0, IsUse: 0 },
	{ Id: 106, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 107, Code: '260', IsShow: 0, IsUse: 0 },
	{ Id: 108, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 109, Code: '262', IsShow: 0, IsUse: 0 },
	{ Id: 110, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 111, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 112, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 113, Code: '270', IsShow: 0, IsUse: 0 },
	{ Id: 114, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 115, Code: '272', IsShow: 0, IsUse: 0 },
	{ Id: 116, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 117, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 118, Code: '278', IsShow: 0, IsUse: 0 },
	{ Id: 119, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 120, Code: '280', IsShow: 0, IsUse: 0 },
	{ Id: 121, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 122, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 123, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 124, Code: '288', IsShow: 0, IsUse: 0 },
	{ Id: 125, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 126, Code: '290', IsShow: 0, IsUse: 0 },
	{ Id: 127, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 128, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 129, Code: '294', IsShow: 0, IsUse: 0 },
	{ Id: 130, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 131, Code: '301', IsShow: 0, IsUse: 0 },
	{ Id: 132, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 133, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 134, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 135, Code: '307', IsShow: 0, IsUse: 0 },
	{ Id: 136, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 137, Code: '309', IsShow: 0, IsUse: 0 },
	{ Id: 138, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 139, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 140, Code: '315', IsShow: 0, IsUse: 0 },
	{ Id: 141, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 142, Code: '317', IsShow: 0, IsUse: 0 },
	{ Id: 143, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 144, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 145, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 146, Code: '325', IsShow: 0, IsUse: 0 },
	{ Id: 147, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 148, Code: '327', IsShow: 0, IsUse: 0 },
	{ Id: 149, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 150, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 151, Code: '331', IsShow: 0, IsUse: 0 },
	{ Id: 152, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 153, Code: '337', IsShow: 0, IsUse: 0 },
	{ Id: 154, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 155, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 156, Code: '255', IsShow: 0, IsUse: 0 },
	{ Id: 157, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 158, Code: '259', IsShow: 0, IsUse: 0 },
	{ Id: 159, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 160, Code: '263', IsShow: 0, IsUse: 0 },
	{ Id: 161, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 162, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 163, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 164, Code: '269', IsShow: 0, IsUse: 0 },
	{ Id: 165, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 166, Code: '273', IsShow: 0, IsUse: 0 },
	{ Id: 167, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 168, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 169, Code: '277', IsShow: 0, IsUse: 0 },
	{ Id: 170, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 171, Code: '281', IsShow: 0, IsUse: 0 },
	{ Id: 172, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 173, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 174, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 175, Code: '287', IsShow: 0, IsUse: 0 },
	{ Id: 176, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 177, Code: '291', IsShow: 0, IsUse: 0 },
	{ Id: 178, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 179, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 180, Code: '295', IsShow: 0, IsUse: 0 },
	{ Id: 181, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 182, Code: '300', IsShow: 0, IsUse: 0 },
	{ Id: 183, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 184, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 185, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 186, Code: '306', IsShow: 0, IsUse: 0 },
	{ Id: 187, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 188, Code: '310', IsShow: 0, IsUse: 0 },
	{ Id: 189, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 190, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 191, Code: '314', IsShow: 0, IsUse: 0 },
	{ Id: 192, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 193, Code: '318', IsShow: 0, IsUse: 0 },
	{ Id: 194, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 195, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 196, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 197, Code: '324', IsShow: 0, IsUse: 0 },
	{ Id: 198, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 199, Code: '328', IsShow: 0, IsUse: 0 },
	{ Id: 200, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 201, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 202, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 203, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 204, Code: '336', IsShow: 0, IsUse: 0 },
	{ Id: 205, Code: '251', IsShow: 0, IsUse: 0 },
	{ Id: 206, Code: '253', IsShow: 0, IsUse: 0 },
	{ Id: 207, Code: '256', IsShow: 0, IsUse: 0 },
	{ Id: 208, Code: '257', IsShow: 0, IsUse: 0 },
	{ Id: 209, Code: '258', IsShow: 0, IsUse: 0 },
	{ Id: 210, Code: '261', IsShow: 0, IsUse: 0 },
	{ Id: 211, Code: '264', IsShow: 0, IsUse: 0 },
	{ Id: 212, Code: '265', IsShow: 0, IsUse: 0 },
	{ Id: 213, Code: '266', IsShow: 0, IsUse: 0 },
	{ Id: 214, Code: '267', IsShow: 0, IsUse: 0 },
	{ Id: 215, Code: '268', IsShow: 0, IsUse: 0 },
	{ Id: 216, Code: '271', IsShow: 0, IsUse: 0 },
	{ Id: 217, Code: '274', IsShow: 0, IsUse: 0 },
	{ Id: 218, Code: '275', IsShow: 0, IsUse: 0 },
	{ Id: 219, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 220, Code: '276', IsShow: 0, IsUse: 0 },
	{ Id: 221, Code: '279', IsShow: 0, IsUse: 0 },
	{ Id: 222, Code: '282', IsShow: 0, IsUse: 0 },
	{ Id: 223, Code: '283', IsShow: 0, IsUse: 0 },
	{ Id: 224, Code: '284', IsShow: 0, IsUse: 0 },
	{ Id: 225, Code: '285', IsShow: 0, IsUse: 0 },
	{ Id: 226, Code: '286', IsShow: 0, IsUse: 0 },
	{ Id: 227, Code: '289', IsShow: 0, IsUse: 0 },
	{ Id: 228, Code: '292', IsShow: 0, IsUse: 0 },
	{ Id: 229, Code: '293', IsShow: 0, IsUse: 0 },
	{ Id: 230, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 231, Code: '296', IsShow: 0, IsUse: 0 },
	{ Id: 232, Code: '297', IsShow: 0, IsUse: 0 },
	{ Id: 233, Code: '299', IsShow: 0, IsUse: 0 },
	{ Id: 234, Code: '302', IsShow: 0, IsUse: 0 },
	{ Id: 235, Code: '303', IsShow: 0, IsUse: 0 },
	{ Id: 236, Code: '304', IsShow: 0, IsUse: 0 },
	{ Id: 237, Code: '305', IsShow: 0, IsUse: 0 },
	{ Id: 238, Code: '308', IsShow: 0, IsUse: 0 },
	{ Id: 239, Code: '311', IsShow: 0, IsUse: 0 },
	{ Id: 240, Code: '312', IsShow: 0, IsUse: 0 },
	{ Id: 241, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 242, Code: '313', IsShow: 0, IsUse: 0 },
	{ Id: 243, Code: '316', IsShow: 0, IsUse: 0 },
	{ Id: 244, Code: '319', IsShow: 0, IsUse: 0 },
	{ Id: 245, Code: '320', IsShow: 0, IsUse: 0 },
	{ Id: 246, Code: '321', IsShow: 0, IsUse: 0 },
	{ Id: 247, Code: '322', IsShow: 0, IsUse: 0 },
	{ Id: 248, Code: '323', IsShow: 0, IsUse: 0 },
	{ Id: 249, Code: '326', IsShow: 0, IsUse: 0 },
	{ Id: 250, Code: '329', IsShow: 0, IsUse: 0 },
	{ Id: 251, Code: '330', IsShow: 0, IsUse: 0 },
	{ Id: 252, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 253, Code: '332', IsShow: 0, IsUse: 0 },
	{ Id: 254, Code: '324', IsShow: 0, IsUse: 0 },
	{ Id: 255, Code: '325', IsShow: 0, IsUse: 0 },
	{ Id: 256, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 257, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 258, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 259, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 260, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 261, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 262, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 263, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 264, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 265, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 266, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 267, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 268, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 269, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 270, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 271, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 272, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 273, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 274, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 275, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 276, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 277, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 278, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 279, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 280, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 281, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 282, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 283, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 284, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 285, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 286, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 287, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 288, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 289, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 290, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 291, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 292, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 293, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 294, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 295, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 296, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 297, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 298, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 299, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 300, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 301, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 302, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 303, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 304, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 305, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 306, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 307, Code: '250', IsShow: 0, IsUse: 0 },
	{ Id: 308, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 309, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 310, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 311, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 312, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 313, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 314, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 315, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 316, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 317, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 318, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 319, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 320, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 321, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 322, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 323, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 324, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 325, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 326, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 327, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 328, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 329, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 330, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 331, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 332, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 333, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 334, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 335, Code: '298', IsShow: 0, IsUse: 0 },
	{ Id: 336, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 337, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 338, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 339, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 340, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 341, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 342, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 343, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 344, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 345, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 346, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 347, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 348, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 349, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 350, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 351, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 352, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 353, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 354, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 355, Code: '333', IsShow: 0, IsUse: 0 },
	{ Id: 356, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 357, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 358, Code: '249', IsShow: 0, IsUse: 0 },
	{ Id: 359, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 360, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 361, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 362, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 363, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 364, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 365, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 366, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 367, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 368, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 369, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 370, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 371, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 372, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 373, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 374, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 375, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 376, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 377, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 378, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 379, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 380, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 381, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 382, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 383, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 384, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 385, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 386, Code: '236', IsShow: 0, IsUse: 0 },
	{ Id: 387, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 388, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 389, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 390, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 391, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 392, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 393, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 394, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 395, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 396, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 397, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 398, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 399, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 400, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 401, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 402, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 403, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 404, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 405, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 406, Code: '200', IsShow: 0, IsUse: 0 },
	{ Id: 407, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 408, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 409, Code: '248', IsShow: 0, IsUse: 0 },
	{ Id: 410, Code: '247', IsShow: 0, IsUse: 0 },
	{ Id: 411, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 412, Code: '246', IsShow: 0, IsUse: 0 },
	{ Id: 413, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 414, Code: '245', IsShow: 0, IsUse: 0 },
	{ Id: 415, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 416, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 417, Code: '244', IsShow: 0, IsUse: 0 },
	{ Id: 418, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 419, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 420, Code: '243', IsShow: 0, IsUse: 0 },
	{ Id: 421, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 422, Code: '242', IsShow: 0, IsUse: 0 },
	{ Id: 423, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 424, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 425, Code: '241', IsShow: 0, IsUse: 0 },
	{ Id: 426, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 427, Code: '240', IsShow: 0, IsUse: 0 },
	{ Id: 428, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 429, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 430, Code: '239', IsShow: 0, IsUse: 0 },
	{ Id: 431, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 432, Code: '238', IsShow: 0, IsUse: 0 },
	{ Id: 433, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 434, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 435, Code: '237', IsShow: 0, IsUse: 0 },
	{ Id: 436, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 437, Code: '235', IsShow: 0, IsUse: 0 },
	{ Id: 438, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 439, Code: '233', IsShow: 0, IsUse: 0 },
	{ Id: 440, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 441, Code: '232', IsShow: 0, IsUse: 0 },
	{ Id: 442, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 443, Code: '231', IsShow: 0, IsUse: 0 },
	{ Id: 444, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 445, Code: '228', IsShow: 0, IsUse: 0 },
	{ Id: 446, Code: '225', IsShow: 0, IsUse: 0 },
	{ Id: 447, Code: '222', IsShow: 0, IsUse: 0 },
	{ Id: 448, Code: '219', IsShow: 0, IsUse: 0 },
	{ Id: 449, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 450, Code: '218', IsShow: 0, IsUse: 0 },
	{ Id: 451, Code: '215', IsShow: 0, IsUse: 0 },
	{ Id: 452, Code: '212', IsShow: 0, IsUse: 0 },
	{ Id: 453, Code: '209', IsShow: 0, IsUse: 0 },
	{ Id: 454, Code: '206', IsShow: 0, IsUse: 0 },
	{ Id: 455, Code: '203', IsShow: 0, IsUse: 0 },
	{ Id: 456, Code: '202', IsShow: 0, IsUse: 0 },
	{ Id: 457, Code: '201', IsShow: 0, IsUse: 0 },
	{ Id: 458, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 459, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 460, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 461, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 462, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 463, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 464, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 465, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 466, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 467, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 468, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 469, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 470, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 471, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 472, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 473, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 474, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 475, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 476, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 477, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 478, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 479, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 480, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 481, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 482, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 483, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 484, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 485, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 486, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 487, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 488, Code: '234', IsShow: 0, IsUse: 0 },
	{ Id: 489, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 490, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 491, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 492, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 493, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 494, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 495, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 496, Code: '229', IsShow: 0, IsUse: 0 },
	{ Id: 497, Code: '226', IsShow: 0, IsUse: 0 },
	{ Id: 498, Code: '223', IsShow: 0, IsUse: 0 },
	{ Id: 499, Code: '220', IsShow: 0, IsUse: 0 },
	{ Id: 500, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 501, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 502, Code: '216', IsShow: 0, IsUse: 0 },
	{ Id: 503, Code: '213', IsShow: 0, IsUse: 0 },
	{ Id: 504, Code: '210', IsShow: 0, IsUse: 0 },
	{ Id: 505, Code: '207', IsShow: 0, IsUse: 0 },
	{ Id: 506, Code: '204', IsShow: 0, IsUse: 0 },
	{ Id: 507, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 508, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 509, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 510, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 511, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 512, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 513, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 514, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 515, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 516, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 517, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 518, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 519, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 520, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 521, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 522, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 523, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 524, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 525, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 526, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 527, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 528, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 529, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 530, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 531, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 532, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 533, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 534, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 535, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 536, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 537, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 538, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 539, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 540, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 541, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 542, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 543, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 544, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 545, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 546, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 547, Code: '230', IsShow: 0, IsUse: 0 },
	{ Id: 548, Code: '227', IsShow: 0, IsUse: 0 },
	{ Id: 549, Code: '224', IsShow: 0, IsUse: 0 },
	{ Id: 550, Code: '221', IsShow: 0, IsUse: 0 },
	{ Id: 551, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 552, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 553, Code: '217', IsShow: 0, IsUse: 0 },
	{ Id: 554, Code: '214', IsShow: 0, IsUse: 0 },
	{ Id: 555, Code: '211', IsShow: 0, IsUse: 0 },
	{ Id: 556, Code: '208', IsShow: 0, IsUse: 0 },
	{ Id: 557, Code: '205', IsShow: 0, IsUse: 0 },
	{ Id: 558, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 559, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 560, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 561, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 562, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 563, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 564, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 565, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 566, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 567, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 568, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 569, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 570, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 571, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 572, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 573, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 574, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 575, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 576, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 577, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 578, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 579, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 580, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 581, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 582, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 583, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 584, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 585, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 586, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 587, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 588, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 589, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 590, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 591, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 592, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 593, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 594, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 595, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 596, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 597, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 598, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 599, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 600, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 601, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 602, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 603, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 604, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 605, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 606, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 607, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 608, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 609, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 610, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 611, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 612, Code: '', IsShow: 1, IsUse: 0 },
]);
//三层输送线数据
const cellsDataThree = ref([
	{ Id: 1, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 2, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 3, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 4, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 5, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 6, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 7, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 8, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 9, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 10, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 11, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 12, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 13, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 14, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 15, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 16, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 17, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 18, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 19, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 20, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 21, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 22, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 23, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 24, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 25, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 26, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 27, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 28, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 29, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 30, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 31, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 32, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 33, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 34, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 35, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 36, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 37, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 38, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 39, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 40, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 41, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 42, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 43, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 44, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 45, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 46, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 47, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 48, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 49, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 50, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 51, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 52, Code: '401', IsShow: 0, IsUse: 0 },
	{ Id: 53, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 54, Code: '402', IsShow: 0, IsUse: 0 },
	{ Id: 55, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 56, Code: '405', IsShow: 0, IsUse: 0 },
	{ Id: 57, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 58, Code: '406', IsShow: 0, IsUse: 0 },
	{ Id: 59, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 60, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 61, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 62, Code: '409', IsShow: 0, IsUse: 0 },
	{ Id: 63, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 64, Code: '410', IsShow: 0, IsUse: 0 },
	{ Id: 65, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 66, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 67, Code: '413', IsShow: 0, IsUse: 0 },
	{ Id: 68, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 69, Code: '414', IsShow: 0, IsUse: 0 },
	{ Id: 70, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 71, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 72, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 73, Code: '417', IsShow: 0, IsUse: 0 },
	{ Id: 74, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 75, Code: '418', IsShow: 0, IsUse: 0 },
	{ Id: 76, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 77, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 78, Code: '421', IsShow: 0, IsUse: 0 },
	{ Id: 79, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 80, Code: '422', IsShow: 0, IsUse: 0 },
	{ Id: 81, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 82, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 83, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 84, Code: '425', IsShow: 0, IsUse: 0 },
	{ Id: 85, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 86, Code: '426', IsShow: 0, IsUse: 0 },
	{ Id: 87, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 88, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 89, Code: '429', IsShow: 0, IsUse: 0 },
	{ Id: 90, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 91, Code: '430', IsShow: 0, IsUse: 0 },
	{ Id: 92, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 93, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 94, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 95, Code: '433', IsShow: 0, IsUse: 0 },
	{ Id: 96, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 97, Code: '434', IsShow: 0, IsUse: 0 },
	{ Id: 98, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 99, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 100, Code: '437', IsShow: 0, IsUse: 0 },
	{ Id: 101, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 102, Code: '438', IsShow: 0, IsUse: 0 },
	{ Id: 103, Code: '400', IsShow: 0, IsUse: 0 },
	{ Id: 104, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 105, Code: '403', IsShow: 0, IsUse: 0 },
	{ Id: 106, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 107, Code: '404', IsShow: 0, IsUse: 0 },
	{ Id: 108, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 109, Code: '407', IsShow: 0, IsUse: 0 },
	{ Id: 110, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 111, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 112, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 113, Code: '408', IsShow: 0, IsUse: 0 },
	{ Id: 114, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 115, Code: '411', IsShow: 0, IsUse: 0 },
	{ Id: 116, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 117, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 118, Code: '412', IsShow: 0, IsUse: 0 },
	{ Id: 119, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 120, Code: '415', IsShow: 0, IsUse: 0 },
	{ Id: 121, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 122, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 123, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 124, Code: '416', IsShow: 0, IsUse: 0 },
	{ Id: 125, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 126, Code: '419', IsShow: 0, IsUse: 0 },
	{ Id: 127, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 128, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 129, Code: '420', IsShow: 0, IsUse: 0 },
	{ Id: 130, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 131, Code: '423', IsShow: 0, IsUse: 0 },
	{ Id: 132, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 133, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 134, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 135, Code: '424', IsShow: 0, IsUse: 0 },
	{ Id: 136, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 137, Code: '427', IsShow: 0, IsUse: 0 },
	{ Id: 138, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 139, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 140, Code: '428', IsShow: 0, IsUse: 0 },
	{ Id: 141, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 142, Code: '431', IsShow: 0, IsUse: 0 },
	{ Id: 143, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 144, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 145, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 146, Code: '432', IsShow: 0, IsUse: 0 },
	{ Id: 147, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 148, Code: '435', IsShow: 0, IsUse: 0 },
	{ Id: 149, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 150, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 151, Code: '436', IsShow: 0, IsUse: 0 },
	{ Id: 152, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 153, Code: '439', IsShow: 0, IsUse: 0 },
	{ Id: 154, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 155, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 156, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 157, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 158, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 159, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 160, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 161, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 162, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 163, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 164, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 165, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 166, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 167, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 168, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 169, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 170, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 171, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 172, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 173, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 174, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 175, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 176, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 177, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 178, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 179, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 180, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 181, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 182, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 183, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 184, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 185, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 186, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 187, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 188, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 189, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 190, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 191, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 192, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 193, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 194, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 195, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 196, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 197, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 198, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 199, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 200, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 201, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 202, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 203, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 204, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 205, Code: '', IsShow: 0, IsUse: 3 },
	{ Id: 206, Code: '', IsShow: 0, IsUse: 3 },
	{ Id: 207, Code: '', IsShow: 0, IsUse: 3 },
	{ Id: 208, Code: '', IsShow: 0, IsUse: 3 },
	{ Id: 209, Code: '', IsShow: 0, IsUse: 3 },
	{ Id: 210, Code: '', IsShow: 0, IsUse: 3 },
	{ Id: 211, Code: '', IsShow: 0, IsUse: 3 },
	{ Id: 212, Code: '', IsShow: 0, IsUse: 3 },
	{ Id: 213, Code: '', IsShow: 0, IsUse: 3 },
	{ Id: 214, Code: '', IsShow: 0, IsUse: 3 },
	{ Id: 215, Code: '', IsShow: 0, IsUse: 3 },
	{ Id: 216, Code: '', IsShow: 0, IsUse: 3 },
	{ Id: 217, Code: '', IsShow: 0, IsUse: 3 },
	{ Id: 218, Code: '', IsShow: 0, IsUse: 3 },
	{ Id: 219, Code: '', IsShow: 0, IsUse: 3 },
	{ Id: 220, Code: '', IsShow: 0, IsUse: 3 },
	{ Id: 221, Code: '', IsShow: 0, IsUse: 3 },
	{ Id: 222, Code: '', IsShow: 0, IsUse: 3 },
	{ Id: 223, Code: '', IsShow: 0, IsUse: 3 },
	{ Id: 224, Code: '', IsShow: 0, IsUse: 3 },
	{ Id: 225, Code: '', IsShow: 0, IsUse: 3 },
	{ Id: 226, Code: '', IsShow: 0, IsUse: 3 },
	{ Id: 227, Code: '', IsShow: 0, IsUse: 3 },
	{ Id: 228, Code: '', IsShow: 0, IsUse: 3 },
	{ Id: 229, Code: '', IsShow: 0, IsUse: 3 },
	{ Id: 230, Code: '', IsShow: 0, IsUse: 3 },
	{ Id: 231, Code: '', IsShow: 0, IsUse: 3 },
	{ Id: 232, Code: '', IsShow: 0, IsUse: 3 },
	{ Id: 233, Code: '', IsShow: 0, IsUse: 3 },
	{ Id: 234, Code: '', IsShow: 0, IsUse: 3 },
	{ Id: 235, Code: '', IsShow: 0, IsUse: 3 },
	{ Id: 236, Code: '', IsShow: 0, IsUse: 3 },
	{ Id: 237, Code: '', IsShow: 0, IsUse: 3 },
	{ Id: 238, Code: '', IsShow: 0, IsUse: 3 },
	{ Id: 239, Code: '', IsShow: 0, IsUse: 3 },
	{ Id: 240, Code: '', IsShow: 0, IsUse: 3 },
	{ Id: 241, Code: '', IsShow: 0, IsUse: 3 },
	{ Id: 242, Code: '', IsShow: 0, IsUse: 3 },
	{ Id: 243, Code: '', IsShow: 0, IsUse: 3 },
	{ Id: 244, Code: '', IsShow: 0, IsUse: 3 },
	{ Id: 245, Code: '', IsShow: 0, IsUse: 3 },
	{ Id: 246, Code: '', IsShow: 0, IsUse: 3 },
	{ Id: 247, Code: '', IsShow: 0, IsUse: 3 },
	{ Id: 248, Code: '', IsShow: 0, IsUse: 3 },
	{ Id: 249, Code: '', IsShow: 0, IsUse: 3 },
	{ Id: 250, Code: '', IsShow: 0, IsUse: 3 },
	{ Id: 251, Code: '', IsShow: 0, IsUse: 3 },
	{ Id: 252, Code: '', IsShow: 0, IsUse: 3 },
	{ Id: 253, Code: '', IsShow: 0, IsUse: 3 },
	{ Id: 254, Code: '', IsShow: 0, IsUse: 3 },
	{ Id: 255, Code: '', IsShow: 0, IsUse: 3 },
	{ Id: 256, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 257, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 258, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 259, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 260, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 261, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 262, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 263, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 264, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 265, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 266, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 267, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 268, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 269, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 270, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 271, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 272, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 273, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 274, Code: '445', IsShow: 0, IsUse: 0 },
	{ Id: 275, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 276, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 277, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 278, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 279, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 280, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 281, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 282, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 283, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 284, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 285, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 286, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 287, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 288, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 289, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 290, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 291, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 292, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 293, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 294, Code: '442', IsShow: 0, IsUse: 0 },
	{ Id: 295, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 296, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 297, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 298, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 299, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 300, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 301, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 302, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 303, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 304, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 305, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 306, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 307, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 308, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 309, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 310, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 311, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 312, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 313, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 314, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 315, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 316, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 317, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 318, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 319, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 320, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 321, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 322, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 323, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 324, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 325, Code: '444', IsShow: 0, IsUse: 0 },
	{ Id: 326, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 327, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 328, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 329, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 330, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 331, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 332, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 333, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 334, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 335, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 336, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 337, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 338, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 339, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 340, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 341, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 342, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 343, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 344, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 345, Code: '441', IsShow: 0, IsUse: 0 },
	{ Id: 346, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 347, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 348, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 349, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 350, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 351, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 352, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 353, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 354, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 355, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 356, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 357, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 358, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 359, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 360, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 361, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 362, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 363, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 364, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 365, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 366, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 367, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 368, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 369, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 370, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 371, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 372, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 373, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 374, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 375, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 376, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 377, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 378, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 379, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 380, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 381, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 382, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 383, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 384, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 385, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 386, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 387, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 388, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 389, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 390, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 391, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 392, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 393, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 394, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 395, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 396, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 397, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 398, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 399, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 400, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 401, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 402, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 403, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 404, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 405, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 406, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 407, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 408, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 409, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 410, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 411, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 412, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 413, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 414, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 415, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 416, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 417, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 418, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 419, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 420, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 421, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 422, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 423, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 424, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 425, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 426, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 427, Code: '443', IsShow: 0, IsUse: 0 },
	{ Id: 428, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 429, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 430, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 431, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 432, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 433, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 434, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 435, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 436, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 437, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 438, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 439, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 440, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 441, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 442, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 443, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 444, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 445, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 446, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 447, Code: '440', IsShow: 0, IsUse: 0 },
	{ Id: 448, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 449, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 450, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 451, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 452, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 453, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 454, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 455, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 456, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 457, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 458, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 459, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 460, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 461, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 462, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 463, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 464, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 465, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 466, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 467, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 468, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 469, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 470, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 471, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 472, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 473, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 474, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 475, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 476, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 477, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 478, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 479, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 480, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 481, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 482, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 483, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 484, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 485, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 486, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 487, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 488, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 489, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 490, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 491, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 492, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 493, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 494, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 495, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 496, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 497, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 498, Code: '', IsShow: 0, IsUse: 2 },
	{ Id: 499, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 500, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 501, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 502, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 503, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 504, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 505, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 506, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 507, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 508, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 509, Code: '', IsShow: 1, IsUse: 0 },
	{ Id: 510, Code: '', IsShow: 1, IsUse: 0 },
]);
//加载输送线数据
let cellsData = ref<any>([]);

const tableParams = ref({
	page: 1,
	pageSize: 10,
	total: 0,
});
const loading = ref(false);
const tableData = ref<any>([]);
const handleQuery = async () => {
	loading.value = true;
	var res = await listWcsAlarmInfo({ status: 1 });
	tableData.value = res.data.result;
	tableParams.value.total = tableData.value.length;

	// 更新输送线数据
	updateCells(cellsDataOne.value);
	updateCells(cellsDataTwo.value);
	updateCells(cellsDataThree.value);

	//加载输送线数据
	cellsData.value = cellsDataOne.value;

	console.log(tableParams.value.total);
	loading.value = false;
};
// 更新输送线数据的通用函数
function updateCells(cellsData: any[]) {
	tableData.value.forEach((item) => {
		updateCellData(cellsData, item);
	});
}
handleQuery();

//复位报警
const reset = async () => {
	await resetWcsAlarmInfo({ layer: layer.value });
	// await handleQuery();
}

const layer = ref(1);
//切换层平面
function floorTogglePlain(buttonNumber) {
	layer.value = buttonNumber;
	if (buttonNumber === 1) {
		//切换输送线数据
		cellsData.value = cellsDataOne.value;
	} else if (buttonNumber === 2) {
		//切换输送线数据
		cellsData.value = cellsDataTwo.value;
	} else if (buttonNumber === 3) {
		//切换输送线数据
		cellsData.value = cellsDataThree.value;
	}
}
</script>

<style scoped>
.box-card {
	height: 30px;
	padding: 0 20px;
	display: flex;
	align-items: center;
}

.card-page {
	width: 100%;
	height: 30px;
	display: flex;
	text-align: center;
	justify-content: center;
	align-items: center;
	text-align: center;
}

.card-page>button {
	width: 150px;
	height: 30px;
}

.card-line {
	border: none;
	background-color: transparent;
	position: absolute;
	z-index: 99;
}

.grid-container-line {
	display: grid;
	grid-template-columns: repeat(51, 1fr);
	/* 自适应列宽 */
	grid-template-rows: 1fr;
	/* 自适应行高 */
	gap: 0;
	margin-top: 25px;
	width: 100%;
	/* 宽度自适应 */
	height: 1fr;
	/* 高度自适应 */
}

.grid-item-line {
	text-align: center;
	line-height: 50px;
	/* Vertical center the content */
	font-size: 12px;
	/* Adjust font size */
	width: 20px;
	height: 100%;
	color: #fff;
	font-size: 14px;

	display: flex;
	justify-content: center;
}

.grid-item-line-end {
	width: 70px;
	height: 25px;
	border: 2px solid #797777;
	background-color: rgb(182, 180, 180);
	position: absolute;
	margin-top: -25px;
	display: flex;
	text-align: center;
	justify-content: center;
	align-items: center;
	text-align: center;
	color: #fff;
}

.grid-item-line-box {
	width: 18px;
	height: 18px;
	background-color: rgb(97, 250, 145);
	position: absolute;
	display: flex;
	text-align: center;
	justify-content: center;
	align-items: center;
	/* Added to vertically center the text */
	text-align: center;
	color: black;
}

.grid-item-line-child {
	height: 220px;
	width: 3px;
	background-color: #000000;
}

.card {
	width: 100%;
	position: absolute;
	border-top: none;
	z-index: 90;
	margin-top: 310px;
}

.grid-container {
	width: 100%;
	display: grid;
	grid-template-columns: repeat(51, 1fr);
	/* 每列宽度 */
	grid-template-rows: repeat(12, 1fr);
	/* 每行高度 */
	gap: 0px;
	/* Gap between cells */

	margin-top: -20px;
	;
}

.grid-item {
	background-color: #9c9c9c;
	border: 1px solid #797777;
	text-align: center;
	line-height: 1.4vw;
	/* 行高 */
	width: 100%;
	/* 自适应宽度 */
	height: 100%;
	/* 自适应高度 */
	color: #fff;
	font-size: 0.6vw;
}

.card {
	width: 100%;
	position: absolute;
	border-top: none;
	z-index: 90;
	margin-top: 310px;
}

.active {
	background-color: rgb(57, 141, 251);
	/* IsUse 为1时背景颜色为蓝色 */
	color: #f5f5f5;
}

.active2>div {
	display: none;
}

.active3 {
	background-color: #fff;
	border: 1px solid red;
}

.active3>div {
	display: none;
}

.active4 {
	background-color: red;
}
</style>